@@ -870,7 +870,7 @@ END
 #END
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}echo -e \"$config_email\" >> /var/www/gnusocial/config.php");
-   if ($twitter_api_key) {
+   if ($twitter_api_key && $twitter_api_key!~/gnusocial_twitter_api/) {
       my $config_twitter=<<END;
 addPlugin(
    'TwitterBridge',
@@ -1042,7 +1042,7 @@ my $gnusocial_setup_summary=sub {
          }
       }
       print "\n   $ip_to_release HAS BEEN RELEASED . . .\n";
-      sleep 5;
+      sleep 4;
    }
    my $num_of_servers=0;
    my $ol=$gnusocial;
@@ -1120,7 +1120,8 @@ our $check_elastic_ip=sub {
 
    my $password="]I[{'gnusocial_enter_password',1}";
    my $confirm="]I[{'gnusocial_enter_password',2}";
-   unless ($password eq $confirm) {
+   if ($password ne $confirm &&
+         (-1==index $password,'gnusocial_enter_password')) {
       STDOUT->autoflush(1);
       print "\n   ERROR: Password entries do not match!";sleep 5;
       STDOUT->autoflush(0);
@@ -1156,19 +1157,19 @@ END
          Name => 'permanent_ip',
          Item_1 => {
 
-            Text => 'Use Elastic (Permanent) IP Address',
-            Result => 
-   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
-
-         },
-         Item_2 => {
-
             Text => 'Stay with Temporary Public IP Address',
             Result =>
    $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
          },
-         Scroll => 2,
+         Item_2 => {
+
+            Text => 'Use Elastic (Permanent) IP Address',
+            Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
+
+         },
+         Scroll => 1,
          Banner => $permanent_ip_banner,
 
       };
@@ -1216,16 +1217,14 @@ END
             Name => 'permanent_ip',
             Item_1 => {
 
-               Text => "Use Elastic (Permanent) IP Address ]C[",
-               Convey => \@available,
+               Text => 'Stay with Temporary Public IP Address',
                Result =>
    $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Item_2 => {
 
-               Text => "Stay with Temporary Public IP Address &\n".
-                       "                 ]C[ (to avoid cost)",
+               Text => "]C[ (to avoid cost)",
                Convey => \@available_remove,
                Result =>
    $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
@@ -1233,12 +1232,13 @@ END
             },
             Item_3 => {
 
-               Text => 'Stay with Temporary Public IP Address',
+               Text => "Use Elastic (Permanent) IP Address ]C[",
+               Convey => \@available,
                Result =>
    $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
-            Scroll => 3,
+            Scroll => 1,
             Banner => $use_elastic_banner,
 
          };
@@ -1264,19 +1264,19 @@ END
             Name => 'permanent_ip',
             Item_1 => {
 
-               Text => 'Allocate Additional Elastic (Permanent) IP Address',
+               Text => 'Stay with Temporary Public IP Address',
                Result =>
    $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
             Item_2 => {
 
-               Text => 'Stay with Temporary Public IP Address',
+               Text => 'Allocate Additional Elastic (Permanent) IP Address',
                Result =>
    $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_site_name,
 
             },
-            Scroll => 2,
+            Scroll => 1,
             Banner => $new_elastic_banner,
 
          };
@@ -1361,6 +1361,7 @@ END
 
 our $gnusocial_ses_sandbox=sub {
 
+   package gnusocial_ses_sandbox;
    my $inform_banner=<<'END';
 
     ___                     _            _     _____        _ 
@@ -1676,12 +1677,14 @@ our $gnusocial_enter_values=sub {
 
    package gnusocial_enter_values;
    my $permanent_ip="]T[{permanent_ip}";
-   if ($permanent_ip=~/Allocate/) {
-      my $c="aws ec2 allocate-address --domain vpc";
-      my ($hash,$output,$error)=
-            &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
-      $hash||={};
-      $permanent_ip=$main::aws->{permanent_ip}=$hash->{PublicIp};
+   if ($main::aws->{permanent_ip}) {
+      $permanent_ip=$main::aws->{permanent_ip};
+   #} elsif ($permanent_ip=~/Allocate/) {
+   #   my $c="aws ec2 allocate-address --domain vpc";
+   #   my ($hash,$output,$error)=
+   #         &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+   #   $hash||={};
+   #   $permanent_ip=$main::aws->{permanent_ip}=$hash->{PublicIp};
    } elsif ($permanent_ip=~s/^.*Elastic.* (\d+\.\d+\.\d+\.\d+).*$/$1/s) {
    } else {
       STDOUT->autoflush(1);
@@ -1727,6 +1730,7 @@ END
 
 our $gnusocial_twitter_app=sub {
 
+   package gnusocial_twitter_app;
    my $twitter_app_banner=<<'END';
 
     ___              _         _          _ _   _               _
@@ -1750,7 +1754,8 @@ END
    my $twitter_app={
 
       Name => 'twitter_app',
-      Result => $gnusocial_enter_values,
+      Result => 
+         $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_values,
       Banner => $twitter_app_banner,
 
    };
@@ -1885,9 +1890,10 @@ END
 
 our $gnusocial_choose_build=sub {
 
+   package gnusocial_choose_build;
    use JSON::XS;
    my $c='wget -qO- https://api.github.com/users/foocorp/repos';
-   my $local=connect_shell();
+   my $local=Net::FullAuto::FA_Core::connect_shell();
    my ($stdout,$stderr)=('','');
    ($stdout,$stderr)=$local->cmd($c);
    my @repos=();
@@ -1934,7 +1940,8 @@ END
          Text => ']C[',
          Convey => \@builds,
          #Result => $gnusocial_setup_summary
-         Result => $gnusocial_twitter_bridge,
+         Result => 
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_twitter_bridge,
 
       },
       Scroll => $scrollnum,
@@ -1993,6 +2000,8 @@ our $gnusocial_enter_site_name=sub {
 
    package gnusocial_enter_site_name;
    my $permanent_ip="]T[{permanent_ip}";
+   my $remember="]I[{'gnusocial_enter_site_name',1}";
+   $remember='' if -1<index $remember,'gnusocial_enter_site_name';
    if ($permanent_ip=~/^["]Release.* (\d+\.\d+\.\d+\.\d+).*$/s) {
       my $ip_to_release=$1;
       my $c="aws ec2 describe-addresses";
@@ -2010,9 +2019,10 @@ our $gnusocial_enter_site_name=sub {
       }
       print "\n   $ip_to_release HAS BEEN RELEASED . . .\n";
       sleep 5;
+      return $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip->();
    } elsif ($permanent_ip=~/(\d+\.\d+\.\d+\.\d+)/s) {
       $main::aws->{permanent_ip}=$1;
-   } elsif ($permanent_ip=~/Elastic \(Permanent\)/) {
+   } elsif ($permanent_ip=~/Allocate|Elastic \(Permanent\)/) { 
       my $c="aws ec2 allocate-address --domain vpc";
       my ($hash,$output,$error)=
             &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
@@ -2040,7 +2050,7 @@ END
 
 
    Site Name
-                    ]I[{1,'',50}
+                    ]I[{1,\'$remember\',50}
 
 END
 
@@ -2163,6 +2173,7 @@ END
 
 our $select_gnusocial_setup=sub {
 
+   package select_gnusocial_setup;
    my @options=('GNU Social & MySQL & NGINX on 1 Server');
    my $gnusocial_setup_banner=<<'END';
 
@@ -2188,7 +2199,8 @@ END
 
          Text => ']C[',
          Convey => \@options,
-         Result => $gnusocial_pick_email_address,
+         Result => 
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_pick_email_address,
          #Result => $gnusocial_enter_domain_name,
 
       },
